---
name: Bug Report
about: '"Something''s wrong..."'
title: ''
labels: ''
assignees: ''

---

## Description
*A clear description of the bug*




## Expected Behavior
*What did you expect to happen instead?*




## Reproduction
*A minimal example that exhibits the behavior.*




## Environment
*Any additional information about your environment*
